@@ -1,8 +1,21 @@
 (TeX-add-style-hook "gWidgets"
- (function
-  (lambda ()
+ (lambda ()
     (LaTeX-add-environments
      "RArgs")
+    (LaTeX-add-labels
+     "fig:basic-widgets"
+     "fig:hello-world"
+     "fig:confirmDialog"
+     "sec:browseEnv"
+     "sec:repeating-plot"
+     "fig:gtkdensity"
+     "fig:Rmail"
+     "fig:doPlot"
+     "fig:notebook"
+     "fig:filebrowser"
+     "sec:using-ggenericwidget"
+     "sec:an-altern-ggenericwidget"
+     "fig:gfunction")
     (TeX-add-symbols
      '("RListel" 1)
      '("RArg" 1)
@@ -11,7 +24,6 @@
      '("RCode" 1)
      "VERSION")
     (TeX-run-style-hooks
-     "fancyhdr"
      "jvfloatstyle"
      "fancyhdr"
      "fancyvrb"
@@ -29,5 +41,5 @@
      "latex2e"
      "art12"
      "article"
-     "12pt"))))
+     "12pt")))
 
